@@ -1,10 +1,11 @@
+{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 import Control.Monad
 import qualified Data.ByteString.Lazy as BL
 import Data.Char (toLower)
 import qualified Data.Map as Map
-import Data.Monoid
+import Data.Maybe (fromMaybe)
 import qualified Data.Text as Text
 import qualified Data.Text.IO as Text
 import Data.Version (showVersion)
@@ -17,8 +18,12 @@ import System.IO (hPutStrLn, stderr)
 import Text.Blaze.Html.Renderer.String
 import qualified Text.Blaze.Html5 as H
 import qualified Text.Blaze.Html5.Attributes as A
+import Text.Read (readMaybe)
 import Text.Printf (printf)
 import Text.Show.Pretty (ppShow)
+#if !MIN_VERSION_base(4,11,0)
+import Data.Semigroup ((<>))
+#endif
 
 data Flag = Sty String
           | Theme String
@@ -27,6 +32,7 @@ data Flag = Sty String
           | Fragment
           | List
           | NumberLines
+          | StartNumber String
           | Syn String
           | TitleAttributes
           | ColorLevel String
@@ -71,6 +77,10 @@ options =
           ["number-lines"]
           (NoArg NumberLines)
           "number lines"
+  ,Option ['N']
+          ["number-lines-from"]
+          (ReqArg StartNumber "NUMBER")
+          "number lines from"
   ,Option ['s']
           ["syntax"]
           (ReqArg Syn "SYNTAX")
@@ -106,6 +116,11 @@ syntaxOf smap _ (Syn lang : _) = do
          Nothing -> err ("Could not find syntax definition for " ++ lang)
 syntaxOf smap fps (_:xs) = syntaxOf smap fps xs
 
+startNumberOf :: [Flag] -> Maybe Int
+startNumberOf []                  = Nothing
+startNumberOf (StartNumber n : _) = readMaybe n
+startNumberOf (_ : xs)            = startNumberOf xs
+
 styleOf :: [Flag] -> IO Style
 styleOf [] = return kate
 styleOf (Theme fp : _) = do
@@ -207,6 +222,7 @@ main = do
   let highlightOpts = defaultFormatOpts{ titleAttributes = TitleAttributes `elem` opts
                                        , numberLines = NumberLines `elem` opts
                                        , lineAnchors = NumberLines `elem` opts
+                                       , startNumber = 1 `fromMaybe` startNumberOf opts
                                        , ansiColorLevel = actualColorLevel
                                        }
   let fragment = Fragment `elem` opts
